"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
exports.networkRefreshTokenHandler = exports.getRetryTimeout = exports.getTimeout = void 0;
exports.resetInitialized = resetInitialized;
const axios_1 = __importStar(require("axios"));
const getTimeout = () => {
    try {
        if (window) {
            return 20000;
        }
        if (process.env.NODE_ENV === 'test') {
            return 500;
        }
        // eslint-disable-next-line @typescript-eslint/no-unused-vars
    }
    catch (e) {
        if (process.env.NODE_ENV === 'test') {
            return 500;
        }
    }
    return 20000;
};
exports.getTimeout = getTimeout;
const getRetryTimeout = () => {
    try {
        if (window) {
            return 35000;
        }
        if (process.env.NODE_ENV === 'test') {
            return 4000;
        }
        // eslint-disable-next-line @typescript-eslint/no-unused-vars
    }
    catch (e) {
        if (process.env.NODE_ENV === 'test') {
            return 4000;
        }
    }
    return 35000;
};
exports.getRetryTimeout = getRetryTimeout;
const ax = axios_1.default.create({
    baseURL: 'http://localhost:8080',
    timeout: (0, exports.getTimeout)(),
});
let initialized = false;
function resetInitialized() {
    if (process.env.NODE_ENV !== 'test') {
        throw new Error('resetInitialized can be called only in test environment');
    }
    initialized = false;
}
function shouldRetry(error, count, limit, started) {
    var _a;
    if ((0, axios_1.isAxiosError)(error) && ((_a = error.response) === null || _a === void 0 ? void 0 : _a.status) === 404) {
        return false;
    }
    // console.log(
    //   'initialized',
    //   initialized,
    //   started,
    //   Date.now(),
    //   'diff',
    //   started && Date.now() - started,
    // );
    // retry for at least 35s if not yet initialized
    if (!initialized && started && Date.now() - started < (0, exports.getRetryTimeout)()) {
        return true;
    }
    return !initialized && count < limit;
}
/**
 * Network refresh token storage handler.
 * Compliant with <strong><em>/api/setdata</em></strong> and <strong><em>/api/getdata</em></strong> endpoints of Kiosk Local Service.
 */
exports.networkRefreshTokenHandler = {
    setRefreshToken(tenant, refreshToken, count = 1) {
        return ax
            .post('/api/setdata', {
            createdAt: Date.now(),
            updatedAt: Date.now(),
            name: `${tenant}_refresh_token`,
            value: refreshToken,
        })
            .then(() => {
            return;
        })
            .catch((err) => {
            if (shouldRetry(err, count, 3)) {
                return exports.networkRefreshTokenHandler.setRefreshToken(tenant, refreshToken, 
                // @ts-expect-error count not to be used by external callers
                count + 1);
            }
            console.error('error saving refresh token', err);
            return;
        });
    },
    getRefreshToken(tenant, 
    // eslint-disable-next-line @typescript-eslint/no-empty-object-type
    options) {
        const started = (options === null || options === void 0 ? void 0 : options.started) || Date.now();
        if (options === null || options === void 0 ? void 0 : options.attemptCallback) {
            options.attemptCallback();
        }
        const count = (options === null || options === void 0 ? void 0 : options.count) || 1;
        return ax
            .post('/api/getdata', { name: `${tenant}_refresh_token` })
            .then(({ data }) => {
            initialized = true;
            return data.value;
        })
            .catch((err) => {
            if (shouldRetry(err, count, 10, started)) {
                // @ts-expect-error count not to be used by external callers
                return exports.networkRefreshTokenHandler.getRefreshToken(tenant, {
                    count: count + 1,
                    attemptCallback: options === null || options === void 0 ? void 0 : options.attemptCallback,
                    started,
                });
            }
            // console.error('error getting refresh token', err);
            return '';
        });
    },
    clearRefreshToken(tenant, count = 1) {
        return ax
            .post('/api/setdata', {
            createdAt: Date.now(),
            updatedAt: Date.now(),
            name: `${tenant}_refresh_token`,
            value: '',
        })
            .then(() => {
            return;
        })
            .catch((err) => {
            if (shouldRetry(err, count, 3)) {
                return exports.networkRefreshTokenHandler.clearRefreshToken(tenant, 
                // @ts-expect-error count not to be used by external callers
                count + 1);
            }
            console.error('error removing refresh token', err.message, err);
            return;
        });
    },
};
